==> mediawiki-1.3.9.tgz: mediawiki/languages/Names.php <==
<?php
/* private */ $wgLanguageNames = array(
	'aa' => 'Afar',			# Afar
	'ab' => 'Abkhazian',	# Abkhazian - FIXME
	'af' => 'Afrikaans',	# Afrikaans
	'ak' => 'Akana',		# Akan
        'an' => 'Aragon&eacute;s',      # Aragonese
	'als' => 'Alemannisch', # Alemannic
	'am' => '&#4768;&#4635;&#4653;&#4763;',	# Amharic
	'ar' => '&#1575;&#1604;&#1593;&#1585;&#1576;&#1610;&#1577;',	# Arabic
	'arc' => '&#1813;&#1829;&#1810;&#1834;&#1848;&#1821;&#1819;',	# Aramaic
	'as' => '&#2437;&#2488;&#2478;&#2496;&#2527;&#2494;',	# Assamese
        'ast' => 'Asturianu',  # Asturian, See BUG [1004836]
	'av' => '&#1040;&#1074;&#1072;&#1088;',	# Avar
	'ay' => 'Aymar',		# Aymara
	'az' => 'Az&#601;rbaycan',	# Azerbaijani
	'ba' => '&#1041;&#1072;&#1096;&#1185;&#1086;&#1088;&#1090;',	# Bashkir
	'be' => '&#1041;&#1077;&#1083;&#1072;&#1088;&#1091;&#1089;&#1082;&#1072;&#1103;',	# Belarusian ''or'' Byelarussian
	'bg' => '&#1041;&#1098;&#1083;&#1075;&#1072;&#1088;&#1089;&#1082;&#1080;',	# Bulgarian
	'bh' => '&#2349;&#2379;&#2332;&#2346;&#2369;&#2352;&#2368;',	# Bihara
	'bi' => 'Bislama',		# Bislama
	'bn' => '&#2476;&#2494;&#2434;&#2482;&#2494; - (Bangla)',	# Bengali
        'bm' => 'Bambara',
	'bo' => 'Bod skad',		# Tibetan
	'br' => 'Brezhoneg',	# Breton
	'bs' => 'Bosanski',		# Bosnian
	'ca' => 'Catal&agrave;',	# Catalan
	'ce' => '&#1053;&#1086;&#1093;&#1095;&#1080;&#1081;&#1085;',	# Chechen
	'ch' => 'Chamoru',		# Chamorro
	'cho' => 'Choctaw',
	'chr' => '&#5091;&#5043;&#5033;', # Cherokee
	'chy' => 'Tsets&ecirc;hest&acirc;hese',	# Cheyenne
	'co' => 'Corsu',		# Corsican
	'cr' => 'Nehiyaw',		# Cree
	'cs' => '&#268;esky',	# Czech
	'csb' => 'Kasz&euml;bscziej',	# Cassubian - FIXME
	'cv' => '&#1063;&#1233;&#1074;&#1072;&#1096; - (&#264;&#259;va&#349;)',	# Chuvash
	'cy' => 'Cymraeg',		# Welsh
	'da' => 'Dansk',		# Danish
	'de' => 'Deutsch',		# German
	'dk' => 'Dansk', # 'da' is correct for the language.
	'dv' => 'Dhivehi',		# Dhivehi
	'dz' => 'Dzongkha',	# Bhutani
	'ee' => 'Eve',			# Eve
	'el' => '&#917;&#955;&#955;&#951;&#957;&#953;&#954;&#940;',	# Greek
	'en' => 'English',		# English
	'eo' => 'Esperanto',	# Esperanto
	'es' => 'Espa&ntilde;ol',	# Spanish
	'et' => 'Eesti',		# Estonian
	'eu' => 'Euskara',		# Basque
	'fa' => '&#1601;&#1575;&#1585;&#1587;&#1740;',	# Persian
	'ff' => 'Fulfulde',		# Fulfulde
	'fi' => 'Suomi',		# Finnish
	'fj' => 'Na Vosa Vakaviti',	# Fijian
	'fo' => 'F&oslash;royskt',	# Faroese
	'fr' => 'Fran&ccedil;ais',	# French
	'fy' => 'Frysk',		# Frisian
	'ga' => 'Gaeilge',		# Irish
	'gd' => 'G&agrave;idhlig',	# Scots Gaelic
	'gl' => 'Galego',		# Gallegan
	'gn' => 'Ava&ntilde;e\'&#7869;',	# Guarani
	'gu' => '&#2711;&#2753;&#2716;&#2736;&#2750;&#2724;&#2752;',	# Gujarati
	'gv' => 'Gaelg',		# Manx
	'ha' => '&#1607;&#1614;&#1608;&#1615;&#1587;&#1614;',	# Hausa
	'haw' => 'Hawai`i',		# Hawaiian
	'he' => '&#1506;&#1489;&#1512;&#1497;&#1514;',	# Hebrew
	'hi' => '&#2361;&#2367;&#2344;&#2381;&#2342;&#2368;',	# Hindi
        'ho' => 'Hiri Motu',
	'hr' => 'Hrvatski',		# Croatian
        'ht' => 'Haitian',	# Haitian (FIXME!)
	'hu' => 'Magyar',		# Hungarian
	'hy' => '&#1344;&#1377;&#1397;&#1381;&#1408;&#1381;&#1398;',	# Armenian
	'hz' => 'Otsiherero',	# Herero
	'ia' => 'Interlingua',	# Interlingua (IALA)
	'id' => 'Bahasa Indonesia',	# Indonesian
	'ie' => 'Interlingue',	# Interlingue (Occidental)
	'ig' => 'Igbo',			# Igbo
        'ii' => 'Yi',		# Sichuan Yi (FIXME!)
	'ik' => 'I&ntilde;upiak',	# Inupiak
	'io' => 'Ido',			# Ido
	'is' => '&Iacute;slenska',	# Icelandic,  according to Jeedo@irc
	'it' => 'Italiano',		# Italian
	'iu' => '&#5123;&#5316;&#5251;&#5198;&#5200;&#5222;',	# Inuktitut
	'ja' => '&#26085;&#26412;&#35486;',	# Japanese
	'jv' => 'Bahasa Jawa',	# Javanese
	'ka' => '&#4325;&#4304;&#4320;&#4311;&#4323;&#4314;&#4312;',	# Georgian
        'kg' => 'Kongo',		# Kongo (FIXME!)
	'ki' => 'Kikuyu',		# Kikuyu (FIXME!)
	'kj' => 'Kuanyama',		# Kuanyama (FIXME!)
	'kk' => '&#1179;&#1072;&#1079;&#1072;&#1179;&#1096;&#1072;',	# Kazakh
	'kl' => 'Kalaallisut',	# Greenlandic
	'km' => '&#6039;&#6070;&#6047;&#6070;&#6017;&#6098;&#6040;&#6082;&#6042;',	# Cambodian
	'kn' => '&#3221;&#3240;&#3277;&#3240;&#3233;',	# Kannada
	'ko' => '&#54620;&#44397;&#50612;',	# Korean
	'kr' => 'Kanuri',
	'ks' => '&#2325;&#2358;&#2381;&#2350;&#2368;&#2352;&#2368; - (&#1603;&#1588;&#1605;&#1610;&#1585;&#1610;)',	# Kashmiri
	'ku' => 'Kurd&icirc;',	# Kurdish
	'kv' => 'Komi',
	'kw' => 'Kernewek',		# Cornish
	'ky' => 'K&#305;rg&#305;zca',	# Kirghiz
	'la' => 'Latina',		# Latin
	'lb' => 'L&euml;tzebuergesch',	# Luxemburguish
	'lg' => 'Luganda',		# Ganda
	'li' => 'Limburgs',		# Limburgian
	'ln' => 'Lingala',		# Lingala
	'lo' => 'Pha xa lao',	# Laotian
	'lt' => 'Lietuvi&#371;',	# Lithuanian
	'lv' => 'Latvie&scaron;u',	# Latvian
	'mg' => 'Malagasy',		# Malagasy - FIXME
	'mh' => 'Ebon',			# Marshallese
	'mi' => 'M&#257;ori',	# Maori
	'mk' => '&#1052;&#1072;&#1082;&#1077;&#1076;&#1086;&#1085;&#1089;&#1082;&#1080;',	# Macedonian
	'ml' => '&#3374;&#3378;&#3375;&#3390;&#3379;&#3330;',	# Malayalam
	'mn' => '&#1052;&#1086;&#1085;&#1075;&#1086;&#1083;',	# Mongoloian
	'mo' => 'Moldoveana',	# Moldovan
	'mr' => '&#2350;&#2352;&#2366;&#2336;&#2368;',	# Marathi
	'ms' => 'Bahasa Melayu',	# Malay
	'mt' => 'bil-Malti',	# Maltese
	'mus' => 'Muscogee',
	'my' => 'Myanmasa',	# Burmese
	'na' => 'Ekakair&#361; Naoero',		# Nauruan
	'nb' => 'Norsk (bokm&aring;l)',		# Norwegian (Bokmal)
	'nah' => 'Nahuatl',
	'nds' => 'Plattd&uuml;&uuml;tsch',	# Low German ''or'' Low Saxon
	'ne' => '&#2344;&#2375;&#2346;&#2366;&#2354;&#2368;',	# Nepali
	'ng' => 'Ndonga',
	'nl' => 'Nederlands',	# Dutch
	'nb' => 'Norsk',		# Norwegian [currently using old '''no''' code]
	'ne' => '&#2344;&#2375;&#2346;&#2366;&#2354;&#2368;',	# Nepali
	'nn' => 'Norsk (nynorsk)'	,	# (Norwegian) Nynorsk
	'no' => 'Norsk',		# Norwegian
	'nv' => 'Din&eacute; bizaad',	# Navajo
	'ny' => 'Chi-Chewa',	# Chichewa
	'oc' => 'Occitan',		# Occitan
	'om' => 'Oromoo', 		# Oromo
	'or' => 'Oriya',		# Oriya - FIXME
	'pa' => '&#2346;&#2306;&#2332;&#2366;&#2348;&#2368; / &#2602;&#2588;&#2622;&#2604;&#2624; / &#1662;&#1606;&#1580;&#1575;&#1576;&#1610;',	# Punjabi
	'pi' => '&#2346;&#2366;&#2367;&#2356;',	# Pali
	'pl' => 'Polski',		# Polish
	'ps' => '&#1662;&#1690;&#1578;&#1608;',	# Pashto
	'pt' => 'Portugu&ecirc;s',	# Portuguese
	'qu' => 'Runa Simi',	# Quechua
	'rm' => 'Rumantsch',	# Raeto-Romance
	'rn' => 'Kirundi',		# Kirundi
	'ro' => 'Rom&acirc;n&#259;',	# Romanian
	'roa-rup' => 'Arm&#226;neashti', # Aromanian
	'ru' => '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;',	# Russian
	'rw' => 'Kinyarwanda',
	'sa' => '&#2360;&#2306;&#2360;&#2381;&#2325;&#2371;&#2340;',	# Sanskrit
	'sc' => 'Sardu',	# Sardinian
	'scn' => 'Sicilianu', # Sicilian
	'sd' => '&#2360;&#2367;&#2344;&#2343;&#2367;',	# Sindhi
	'se' => 'S&aacute;megiella',	# (Northern) Sami
	'sg'	=> 'Sangro',
#	'sh'	=> '&#1057;&#1088;&#1087;&#1089;&#1082;&#1086;&#1093;&#1088;&#1074;&#1072;&#1090;&#1089;&#1082;&#1080; (Srbskohrvatski)', ## Serbocroatian -- Obsolete
	'si' => 'Simhala',	# Sinhalese
	'simple' => 'Simple English',
	'sk' => 'Sloven&#269;ina',	# Slovak
	'sl' => 'Sloven&scaron;&#269;ina',	# Slovenian
	'sm' => 'Gagana Samoa',	# Samoan
	'sn' => 'chiShona',		# Shona
	'so' => 'Soomaaliga',	# Somali
	'sq' => 'Shqip',		# Albanian
	'sr' => '&#1057;&#1088;&#1087;&#1089;&#1082;&#1080; / Srpski',	# Serbian
	'ss' => 'SiSwati',		# Swati
	'st' => 'seSotho',		# (Southern) Sotho
	'su' => 'Bahasa Sunda',	# Sundanese
	'sv' => 'Svenska',		# Swedish
	'sw' => 'Kiswahili',	# Swahili
	'ta' => '&#2980;&#2990;&#3007;&#2996;&#3021;',	# Tamil
	'te' => '&#3108;&#3142;&#3122;&#3137;&#3095;&#3137;',	# Telugu
	'tg' => '&#1058;&#1086;&#1207;&#1080;&#1082;&#1251;',	# Tajik
	'th' => '&#3652;&#3607;&#3618;',	# Thai
	'ti' => 'Tigrinya',		# Tigrinya - FIXME
	'tk' => '&#1578;&#1585;&#1603;&#1605;&#1606; / &#1058;&#1091;&#1088;&#1082;&#1084;&#1077;&#1085;',	# Turkmen
	'tl' => 'Tagalog',		# Tagalog (Filipino)
	#'tlh' => 'tlhIngan-Hol',	# Klingon - no interlanguage links allowed
	'tn' => 'Setswana',		# Setswana
	'to' => 'Tonga',		# Tonga - FIXME
	'tokipona' => 'Toki Pona',      # Toki Pona
	'tp' => 'Toki Pona',		# Toki Pona - non-standard language code
	'tpi' => 'Tok Pisin',	# Tok Pisin
	'tr' => 'T&uuml;rk&ccedil;e',	# Turkish
	'ts' => 'Xitsonga',		# Tsonga
	'tt' => 'Tatar',		# Tatar
	'tum' => 'chiTumbuka',  # Tumbuka
	'tw' => 'Twi',			# Twi -- FIXME
	'ty' => 'Reo M&#257;`ohi',	# Tahitian
	'ug' => 'Oyghurque',	# Uyghur
	'uk' => '&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072;',	# Ukrainian
	'ur' => '&#1575;&#1585;&#1583;&#1608;',	# Urdu
	'uz' => '&#1038;&#1079;&#1073;&#1077;&#1082;',	# Uzbek
	've' => 'Venda',		# Venda
	'vi' => 'Ti&#7871;ng Vi&#7879;t',	# Vietnamese
	'vo' => 'Volap&uuml;k',	# Volapük
	'wa' => 'Walon',		# Walloon
	'wo' => 'Wollof',		# Wolof
	'xh' => 'isiXhosa',		# Xhosan
	'yi' => '&#1497;&#1497;&#1460;&#1491;&#1497;&#1513;',	# Yiddish
	'yo' => 'Yor&ugrave;b&aacute;',	# Yoruba
	'za' => '(Cuengh)',		# Zhuang
	'zh' => '&#20013;&#25991;',	# (Zh&#333;ng Wén) - Chinese
	'zh-cfr' => '&#38313;&#21335;&#35486;', # Min-nan
	'zh-cn' => '&#20013;&#25991;(&#31616;&#20307;)',	# Simplified
	'zh-tw' => '&#20013;&#25991;(&#32321;&#20307;)',	# Traditional
	'zu' => 'isiZulu',		# Zulu
);
?>

==> mediawiki-1.4.4.tgz: mediawiki/languages/Names.php <==
<?php
/* private */ $wgLanguageNames = array(
	'aa' => 'Afar',			# Afar
	'ab' => '&#1040;&#1191;&#1089;&#1091;&#1072;',	# Abkhaz, should possibly add ' &#1073;&#1099;&#1089;&#1078;&#1121;&#1072;'
	'af' => 'Afrikaans',	# Afrikaans
	'ak' => 'Akana',		# Akan
	'als' => 'Alemannisch',	# Alemannic
	'am' => '&#4768;&#4635;&#4653;&#4763;',	# Amharic
	'an' => 'Aragon&eacute;s',	# Aragonese
	'ang' => 'Anglo Saxon',	# Old English
	'ar' => '&#1575;&#1604;&#1593;&#1585;&#1576;&#1610;&#1577;',	# Arabic
	'arc' => '&#1813;&#1829;&#1810;&#1834;&#1848;&#1821;&#1819;',	# Aramaic
	'as' => '&#2437;&#2488;&#2478;&#2496;&#2527;&#2494;',	# Assamese
	'ast' => 'Asturianu',	# Asturian
	'av' => '&#1040;&#1074;&#1072;&#1088;',	# Avar
	'ay' => 'Aymar',		# Aymara, should possibly be Aymar&#225;
	'az' => 'Az&#601;rbaycan',	# Azerbaijani
	'ba' => '&#1041;&#1072;&#1096;&#1185;&#1086;&#1088;&#1090;',	# Bashkir
	'be' => '&#1041;&#1077;&#1083;&#1072;&#1088;&#1091;&#1089;&#1082;&#1072;&#1103;',	# Belarusian ''or'' Byelarussian
	'bg' => '&#1041;&#1098;&#1083;&#1075;&#1072;&#1088;&#1089;&#1082;&#1080;',	# Bulgarian
	'bh' => '&#2349;&#2379;&#2332;&#2346;&#2369;&#2352;&#2368;',	# Bihara
	'bi' => 'Bislama',		# Bislama
	'bm' => 'Bamanankan',	# Bambara
	'bn' => '&#2476;&#2494;&#2434;&#2482;&#2494;',	# Bengali
	'bo' => '&#3926;&#3964;&#3921;&#3851;&#3937;&#3954;&#3906;',	# Tibetan
	'br' => 'Brezhoneg',	# Breton
	'bs' => 'Bosanski',		# Bosnian
	'ca' => 'Catal&agrave;',	# Catalan
	'ce' => '&#1053;&#1086;&#1093;&#1095;&#1080;&#1081;&#1085;',	# Chechen
	'ch' => 'Chamoru',		# Chamorro
	'cho' => 'Choctaw',		# Choctaw
	'chr' => '&#5091;&#5043;&#5033;', # Cherokee
	'chy' => 'Tsets&ecirc;hest&acirc;hese',	# Cheyenne
	'co' => 'Corsu',		# Corsican
	'cr' => 'Nehiyaw',		# Cree
	'cs' => '&#268;esky',	# Czech
	'csb' => 'Kasz&euml;bscziej',	# Cassubian, should possibly be Kasz&#235;bsczi
	'cv' => '&#1063;&#1233;&#1074;&#1072;&#1096;',	# Chuvash
	'cy' => 'Cymraeg',		# Welsh
	'da' => 'Dansk',		# Danish
	'de' => 'Deutsch',		# German
	'dk' => 'Dansk', 		# Unused code currently redirecting to Danish, 'da' is correct for the language
	'dv' => '&#1920;&#1960;&#1924;&#1958;&#1936;&#1968;',		# Dhivehi
	'dz' => '&#3911;&#3964;&#3908;&#3851;&#3905;',		# Bhutani
	'ee' => '&#400;&#651;&#603;',	# Ewe
	'el' => '&#917;&#955;&#955;&#951;&#957;&#953;&#954;&#940;',	# Greek
	'en' => 'English',		# English
	'eo' => 'Esperanto',	# Esperanto
	'es' => 'Espa&ntilde;ol',	# Spanish
	'et' => 'Eesti',		# Estonian
	'eu' => 'Euskara',		# Basque
	'fa' => '&#1601;&#1575;&#1585;&#1587;&#1740;',	# Persian
	'ff' => 'Fulfulde',		# Fulah
	'fi' => 'Suomi',		# Finnish
	'fj' => 'Na Vosa Vakaviti',	# Fijian
	'fo' => 'F&oslash;royskt',	# Faroese
	'fr' => 'Fran&ccedil;ais',	# French
	'fur' => 'Furlan',		# Friulian
	'fy' => 'Frysk',		# Frisian
	'ga' => 'Gaeilge',		# Irish
	'gd' => 'G&agrave;idhlig',	# Scots Gaelic
	'gl' => 'Galego',		# Gallegan
	'gn' => 'Ava&ntilde;e\'&#7869;',	# Guarani
	'got' => '&#x10332;&#x1033F;&#x10344;&#x10339;&#x10343;&#x1033A;',	# Gothic
	'gu' => '&#2711;&#2753;&#2716;&#2736;&#2750;&#2724;&#2752;',	# Gujarati
	'gv' => 'Gaelg',		# Manx
	'ha' => '&#1607;&#1614;&#1608;&#1615;&#1587;&#1614;',	# Hausa
	'haw' => 'Hawai`i',		# Hawaiian
	'he' => '&#1506;&#1489;&#1512;&#1497;&#1514;',	# Hebrew
	'hi' => '&#2361;&#2367;&#2344;&#2381;&#2342;&#2368;',	# Hindi
	'ho' => 'Hiri Motu',	# Hiri Motu
	'hr' => 'Hrvatski',		# Croatian
	'ht' => 'Kr&#232;yol ayisyen',		# Haitian, common/popular form is Krey&#242;l
	'hu' => 'Magyar',		# Hungarian
	'hy' => '&#1344;&#1377;&#1397;&#1381;&#1408;&#1381;&#1398;',	# Armenian
	'hz' => 'Otsiherero',	# Herero
	'ia' => 'Interlingua',	# Interlingua (IALA)
	'id' => 'Bahasa Indonesia',	# Indonesian
	'ie' => 'Interlingue',	# Interlingue (Occidental)
	'ig' => 'Igbo',			# Igbo
	'ii' => '&#41351;&#41561;',	# Sichuan Yi
	'ik' => 'I&ntilde;upiak',	# Inupiak
	'io' => 'Ido',			# Ido
	'is' => '&Iacute;slenska',	# Icelandic
	'it' => 'Italiano',		# Italian
	'iu' => '&#5123;&#5316;&#5251;&#5198;&#5200;&#5222;',	# Inuktitut
	'ja' => '&#26085;&#26412;&#35486;',	# Japanese
	'jbo' => 'Lojban',		# Lojban
	'jv' => 'Basa Jawa',	# Javanese
	'ka' => '&#4325;&#4304;&#4320;&#4311;&#4323;&#4314;&#4312;',	# Georgian
	'kg' => 'Kongo',		# Kongo, (FIXME!) should probaly be KiKongo or KiKoongo
	'ki' => 'G&#297;k&#361;y&#361;',	# Kikuyu, correctness not guaranteed
	'kj' => 'Kuanyama',		# Kuanyama (FIXME!)
	'kk' => '&#1179;&#1072;&#1079;&#1072;&#1179;&#1096;&#1072;',	# Kazakh
	'kl' => 'Kalaallisut',	# Greenlandic
	'km' => '&#6039;&#6070;&#6047;&#6070;&#6017;&#6098;&#6040;&#6082;&#6042;',	# Cambodian
	'kn' => '&#3221;&#3240;&#3277;&#3240;&#3233;',	# Kannada
	'ko' => '&#54620;&#44397;&#50612;',	# Korean
	'kr' => 'Kanuri',		# Kanuri (FIXME!)
	'ks' => '&#2325;&#2358;&#2381;&#2350;&#2368;&#2352;&#2368; - (&#1603;&#1588;&#1605;&#1610;&#1585;&#1610;)',	# Kashmiri
	'ku' => 'Kurd&icirc;',	# Kurdish
	'kv' => '&#1050;&#1086;&#1084;&#1080;', 	# Komi, cyrillic is common script but also written in latin script
	'kw' => 'Kernewek',		# Cornish
	'ky' => 'K&#305;rg&#305;zca',	# Kirghiz
	'la' => 'Latina',		# Latin
	'lb' => 'L&euml;tzebuergesch',	# Luxemburguish
	'lg' => 'Luganda',		# Ganda
	'li' => 'L&#232;mburgs',	# Limburgian
	'ln' => 'Lingala',		# Lingala
	'lo' => '&#3749;&#3762;&#3751;',# Laotian
	'lt' => 'Lietuvi&#371;',	# Lithuanian
	'lv' => 'Latvie&scaron;u',	# Latvian
	'mg' => 'Malagasy',		# Malagasy
	'mh' => 'Ebon',			# Marshallese
	'mi' => 'M&#257;ori',	# Maori
	'minnan' => 'B&#226;n-l&#226;m-g&#250;', # Min-nan (also zh-min-nan)
	'mk' => '&#1052;&#1072;&#1082;&#1077;&#1076;&#1086;&#1085;&#1089;&#1082;&#1080;',	# Macedonian
	'ml' => '&#3374;&#3378;&#3375;&#3390;&#3379;&#3330;',	# Malayalam
	'mn' => '&#1052;&#1086;&#1085;&#1075;&#1086;&#1083;',	# Mongoloian
	'mo' => 'Moldoveana',	# Moldovan
	'mr' => '&#2350;&#2352;&#2366;&#2336;&#2368;',	# Marathi
	'ms' => 'Bahasa Melayu',	# Malay
	'mt' => 'bil-Malti',	# Maltese
	'mus' => 'Muscogee',	# Creek, should possibly be Muskogee
	'my' => 'Myanmasa',		# Burmese
	'na' => 'Ekakair&#361; Naoero',		# Nauruan
	'nah' => 'Nahuatl',		# Nahuatl, en:Wikipedia writes Nahuatlahtolli, while another form is N&#225;huatl
	'nb' => 'Norsk (bokm&aring;l)',		# Norwegian (Bokmal)
	'nds' => 'Plattd&uuml;&uuml;tsch',	# Low German ''or'' Low Saxon
	'ne' => '&#2344;&#2375;&#2346;&#2366;&#2354;&#2368;',	# Nepali
	'ng' => 'Oshiwambo',		# Ndonga
	'nl' => 'Nederlands',	# Dutch
	'nn' => 'Norsk (nynorsk)'	,	# Norwegian (Nynorsk)
	'no' => 'Norsk',		# Norwegian
	'non' => 'Norr&#511;na',		# Old Norse
	'nv' => 'Din&eacute; bizaad',	# Navajo
	'ny' => 'Chi-Chewa',	# Chichewa
	'oc' => 'Occitan',		# Occitan
	'om' => 'Oromoo', 		# Oromo
	'or' => '&#2835;&#2908;&#2879;&#2822;',		# Oriya
	'os' => '&#1048;&#1088;&#1086;&#1085;&#1072;&#1091;', # Ossetic
	'pa' => '&#2602;&#2672;&#2588;&#2622;&#2604;&#2624;', # Punjabi
	'pi' => '&#2346;&#2366;&#2367;&#2356;',	# Pali
	'pl' => 'Polski',		# Polish
	'ps' => '&#1662;&#1690;&#1578;&#1608;',	# Pashto
	'pt' => 'Portugu&ecirc;s',	# Portuguese
	'qu' => 'Runa Simi',	# Quechua
	'rm' => 'Rumantsch',	# Raeto-Romance
	'rn' => 'Kirundi',		# Kirundi
	'ro' => 'Rom&acirc;n&#259;',	# Romanian
	'roa-rup' => 'Arm&#226;neashti', # Aromanian
	'ru' => '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;',	# Russian
	'rw' => 'Kinyarwanda',	# Kinyarwanda, should possibly be Kinyarwandi
	'sa' => '&#2360;&#2306;&#2360;&#2381;&#2325;&#2371;&#2340;',	# Sanskrit
	'sc' => 'Sardu',		# Sardinian
	'scn' => 'Sicilianu',	# Sicilian
	'sd' => '&#2360;&#2367;&#2344;&#2343;&#2367;',	# Sindhi
	'se' => 'S&aacute;megiella',	# Northern Sami
	'sg' => 'S&#228;ng&#246;',		# Sango, possible alternative is Sangho
#	'sh'	=> '&#1057;&#1088;&#1087;&#1089;&#1082;&#1086;&#1093;&#1088;&#1074;&#1072;&#1090;&#1089;&#1082;&#1080; (Srbskohrvatski)', ## Serbocroatian -- Obsolete
	'si' => '&#3523;&#3538;&#3458;&#3524;&#3517;',	# Sinhalese
	'simple' => 'Simple English',	# Simple English
	'sk' => 'Sloven&#269;ina',	# Slovak
	'sl' => 'Sloven&scaron;&#269;ina',	# Slovenian
	'sm' => 'Gagana Samoa',	# Samoan
	'sn' => 'chiShona',		# Shona
	'so' => 'Soomaaliga',	# Somali
	'sq' => 'Shqip',		# Albanian
	'sr' => '&#1057;&#1088;&#1087;&#1089;&#1082;&#1080; / Srpski',	# Serbian
	'ss' => 'SiSwati',		# Swati
	'st' => 'seSotho',		# Southern Sotho
	'su' => 'Basa Sunda',	# Sundanese
	'sv' => 'Svenska',		# Swedish
	'sw' => 'Kiswahili',	# Swahili
	'ta' => '&#2980;&#2990;&#3007;&#2996;&#3021;',	# Tamil
	'te' => '&#3108;&#3142;&#3122;&#3137;&#3095;&#3137;',	# Telugu
	'tg' => '&#1058;&#1086;&#1207;&#1080;&#1082;&#1251;',	# Tajik
	'th' => '&#3652;&#3607;&#3618;',	# Thai
	'ti' => '&#4725;&#4877;&#4653;&#4763;',		# Tigrinya
	'tk' => '&#1578;&#1585;&#1603;&#1605;&#1606; / &#1058;&#1091;&#1088;&#1082;&#1084;&#1077;&#1085;',	# Turkmen
	'tl' => 'Tagalog',		# Tagalog (Filipino)
	#'tlh' => 'tlhIngan-Hol',	# Klingon - no interlanguage links allowed
	'tn' => 'Setswana',		# Setswana
	'to' => 'faka-Tonga',		# Tonga (Tonga Islands)
	'tokipona' => 'Toki Pona',      # Toki Pona
	'tp' => 'Toki Pona',	# Toki Pona - non-standard language code
	'tpi' => 'Tok Pisin',	# Tok Pisin
	'tr' => 'T&uuml;rk&ccedil;e',	# Turkish
	'ts' => 'Xitsonga',		# Tsonga
	'tt' => 'Tatar&ccedil;a',	# Tatar
	'tum' => 'chiTumbuka',  # Tumbuka
	'tw' => 'Twi',			# Twi, (FIXME!)
	'ty' => 'Reo M&#257;`ohi',	# Tahitian
	'ug' => 'Oyghurque',	# Uyghur
	'uk' => '&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072;',	# Ukrainian
	'ur' => '&#1575;&#1585;&#1583;&#1608;',	# Urdu
	'uz' => '&#1038;&#1079;&#1073;&#1077;&#1082;',	# Uzbek
	've' => 'Tshivenda',		# Venda
	'vi' => 'Ti&#7871;ng Vi&#7879;t',	# Vietnamese
	'vo' => 'Volap&uuml;k',	# Volapük
	'wa' => 'Walon',		# Walloon
	'wo' => 'Wollof',		# Wolof
	'xh' => 'isiXhosa',		# Xhosan
	'yi' => '&#1497;&#1497;&#1460;&#1491;&#1497;&#1513;',	# Yiddish
	'yo' => 'Yor&ugrave;b&aacute;',	# Yoruba
	'za' => '(Cuengh)',		# Zhuang
	'zh' => '&#20013;&#25991;',	# (Zh&#333;ng Wén) - Chinese
	'zh-cfr' => '&#38313;&#21335;&#35486;', # Min-nan alias (site is at minnan)
	'zh-cn' => '&#20013;&#25991;(&#31616;&#20307;)',	# Simplified
	'zh-hk' => '&#20013;&#25991;(&#32321;&#39636;)',	# Traditional (Hong Kong)
	'zh-min-nan' => 'B&#226;n-l&#226;m-g&#250;', # Min-nan
	'zh-sg' => '&#20013;&#25991;(&#31616;&#20307;)', # Simplified (Singapore)
	'zh-tw' => '&#20013;&#25991;(&#32321;&#39636;)',	# Traditional
	'zu' => 'isiZulu'		# Zulu
);
?>
